pub struct AuthenticateData(pub Secret<Vec<u8>>);Expand description
Data line used, e.g., during AUTHENTICATE.
Holds the raw binary data, i.e., a Vec<u8>, not the BASE64 string.
Tuple Fields
0: Secret<Vec<u8>>Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for AuthenticateData
Available on crate feature arbitrary only.
impl<'arbitrary> Arbitrary<'arbitrary> for AuthenticateData
Available on crate feature
arbitrary only.Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for AuthenticateData
impl Clone for AuthenticateData
Sourcefn clone(&self) -> AuthenticateData
fn clone(&self) -> AuthenticateData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthenticateData
impl Debug for AuthenticateData
Sourceimpl<'de> Deserialize<'de> for AuthenticateData
Available on crate feature serde only.
impl<'de> Deserialize<'de> for AuthenticateData
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuthenticateData
Sourceimpl Hash for AuthenticateData
impl Hash for AuthenticateData
Sourceimpl IntoBoundedStatic for AuthenticateData
Available on crate feature bounded-static only.
impl IntoBoundedStatic for AuthenticateData
Available on crate feature
bounded-static only.Sourcetype Static = AuthenticateData
type Static = AuthenticateData
The target type is bounded by the
'static lifetime.Sourcefn into_static(self) -> Self::Static
fn into_static(self) -> Self::Static
Convert an owned
T into an owned T such that T: 'static.Sourceimpl PartialEq for AuthenticateData
impl PartialEq for AuthenticateData
Sourceimpl Serialize for AuthenticateData
Available on crate feature serde only.
impl Serialize for AuthenticateData
Available on crate feature
serde only.impl StructuralPartialEq for AuthenticateData
Sourceimpl ToBoundedStatic for AuthenticateData
Available on crate feature bounded-static only.
impl ToBoundedStatic for AuthenticateData
Available on crate feature
bounded-static only.Auto Trait Implementations
impl Freeze for AuthenticateData
impl RefUnwindSafe for AuthenticateData
impl Send for AuthenticateData
impl Sync for AuthenticateData
impl Unpin for AuthenticateData
impl UnsafeUnpin for AuthenticateData
impl UnwindSafe for AuthenticateData