pub struct Part(pub NonEmptyVec<NonZeroU32>);Tuple Fields
0: NonEmptyVec<NonZeroU32>Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for Part
Available on crate feature arbitrary only.
impl<'arbitrary> Arbitrary<'arbitrary> for Part
Available on crate feature
arbitrary only.Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl<'de> Deserialize<'de> for Part
Available on crate feature serde only.
impl<'de> Deserialize<'de> for Part
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Part
Sourceimpl IntoBoundedStatic for Part
Available on crate feature bounded-static only.
impl IntoBoundedStatic for Part
Available on crate feature
bounded-static only.impl StructuralPartialEq for Part